# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('materialize')


class _ExportableConfig(types.ModuleType):
    @property
    def base_endpoint(self) -> Optional[str]:
        """
        The base endpoint for Materialize.
        """
        return __config__.get('baseEndpoint') or _utilities.get_env('MZ_BASE_ENDPOINT')

    @property
    def cloud_endpoint(self) -> Optional[str]:
        """
        The endpoint for the Materialize Cloud API.
        """
        return __config__.get('cloudEndpoint') or _utilities.get_env('MZ_CLOUD_ENDPOINT')

    @property
    def database(self) -> Optional[str]:
        """
        The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        """
        return __config__.get('database') or _utilities.get_env('MZ_DATABASE')

    @property
    def default_region(self) -> Optional[str]:
        """
        The default region if not specified in the resource
        """
        return __config__.get('defaultRegion') or _utilities.get_env('MZ_DEFAULT_REGION')

    @property
    def endpoint(self) -> Optional[str]:
        """
        The endpoint for the Materialize API.
        """
        return __config__.get('endpoint') or _utilities.get_env('MZ_ENDPOINT')

    @property
    def password(self) -> Optional[str]:
        """
        Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        """
        return __config__.get('password') or _utilities.get_env('MZ_PASSWORD')

    @property
    def sslmode(self) -> Optional[str]:
        """
        For testing purposes, the SSL mode to use.
        """
        return __config__.get('sslmode') or _utilities.get_env('MZ_SSLMODE')

