# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .app_password import *
from .cluster import *
from .cluster_replica import *
from .connection_aws_privatelink import *
from .connection_confluent_schema_registry import *
from .connection_kafka import *
from .connection_postgres import *
from .connection_ssh_tunnel import *
from .database import *
from .get_cluster_replicas import *
from .get_clusters import *
from .get_connections import *
from .get_current_cluster import *
from .get_current_database import *
from .get_databases import *
from .get_egress_ips import *
from .get_indexes import *
from .get_materialized_views import *
from .get_roles import *
from .get_schemas import *
from .get_scim_configs import *
from .get_scim_groups import *
from .get_secrets import *
from .get_sinks import *
from .get_sources import *
from .get_sso_config import *
from .get_tables import *
from .get_types import *
from .get_views import *
from .grant_cluster import *
from .grant_cluster_default_privilege import *
from .grant_connection import *
from .grant_connection_default_privilege import *
from .grant_database import *
from .grant_database_default_privilege import *
from .grant_materialized_view import *
from .grant_role import *
from .grant_schema import *
from .grant_schema_default_privilege import *
from .grant_secret import *
from .grant_secret_default_privilege import *
from .grant_source import *
from .grant_system_privilege import *
from .grant_table import *
from .grant_table_default_privilege import *
from .grant_type import *
from .grant_type_default_privilege import *
from .grant_view import *
from .index import *
from .materialized_view import *
from .provider import *
from .region import *
from .role import *
from .schema import *
from .scim2_configuration import *
from .secret import *
from .sink_kafka import *
from .source_kafka import *
from .source_loadgen import *
from .source_postgres import *
from .source_webhook import *
from .sso_config import *
from .sso_default_roles import *
from .sso_domain import *
from .sso_role_group_mapping import *
from .table import *
from .type import *
from .user import *
from .view import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_materialize.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_materialize.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "materialize",
  "mod": "index/appPassword",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/appPassword:AppPassword": "AppPassword"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/cluster",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/clusterReplica",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/clusterReplica:ClusterReplica": "ClusterReplica"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionAwsPrivatelink",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionAwsPrivatelink:ConnectionAwsPrivatelink": "ConnectionAwsPrivatelink"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionConfluentSchemaRegistry",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionConfluentSchemaRegistry:ConnectionConfluentSchemaRegistry": "ConnectionConfluentSchemaRegistry"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionKafka",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionKafka:ConnectionKafka": "ConnectionKafka"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionPostgres",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionPostgres:ConnectionPostgres": "ConnectionPostgres"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/connectionSshTunnel",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/connectionSshTunnel:ConnectionSshTunnel": "ConnectionSshTunnel"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/database",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/database:Database": "Database"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantCluster",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantCluster:GrantCluster": "GrantCluster"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantClusterDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantClusterDefaultPrivilege:GrantClusterDefaultPrivilege": "GrantClusterDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantConnection",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantConnection:GrantConnection": "GrantConnection"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantConnectionDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantConnectionDefaultPrivilege:GrantConnectionDefaultPrivilege": "GrantConnectionDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantDatabase",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantDatabase:GrantDatabase": "GrantDatabase"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantDatabaseDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantDatabaseDefaultPrivilege:GrantDatabaseDefaultPrivilege": "GrantDatabaseDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantMaterializedView",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantMaterializedView:GrantMaterializedView": "GrantMaterializedView"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantRole",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantRole:GrantRole": "GrantRole"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSchema",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSchema:GrantSchema": "GrantSchema"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSchemaDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSchemaDefaultPrivilege:GrantSchemaDefaultPrivilege": "GrantSchemaDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSecret",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSecret:GrantSecret": "GrantSecret"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSecretDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSecretDefaultPrivilege:GrantSecretDefaultPrivilege": "GrantSecretDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSource",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSource:GrantSource": "GrantSource"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantSystemPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantSystemPrivilege:GrantSystemPrivilege": "GrantSystemPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantTable",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantTable:GrantTable": "GrantTable"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantTableDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantTableDefaultPrivilege:GrantTableDefaultPrivilege": "GrantTableDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantType",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantType:GrantType": "GrantType"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantTypeDefaultPrivilege",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantTypeDefaultPrivilege:GrantTypeDefaultPrivilege": "GrantTypeDefaultPrivilege"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/grantView",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/grantView:GrantView": "GrantView"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/index",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/index:Index": "Index"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/materializedView",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/materializedView:MaterializedView": "MaterializedView"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/role",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/role:Role": "Role"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sCIM2Configuration",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sCIM2Configuration:SCIM2Configuration": "SCIM2Configuration"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSOConfig",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSOConfig:SSOConfig": "SSOConfig"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSODefaultRoles",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSODefaultRoles:SSODefaultRoles": "SSODefaultRoles"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSODomain",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSODomain:SSODomain": "SSODomain"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sSORoleGroupMapping",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sSORoleGroupMapping:SSORoleGroupMapping": "SSORoleGroupMapping"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/schema",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/secret",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sinkKafka",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sinkKafka:SinkKafka": "SinkKafka"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourceKafka",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourceKafka:SourceKafka": "SourceKafka"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourceLoadgen",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourceLoadgen:SourceLoadgen": "SourceLoadgen"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourcePostgres",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourcePostgres:SourcePostgres": "SourcePostgres"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/sourceWebhook",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/sourceWebhook:SourceWebhook": "SourceWebhook"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/table",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/table:Table": "Table"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/type",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/type:Type": "Type"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/user",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/user:User": "User"
  }
 },
 {
  "pkg": "materialize",
  "mod": "index/view",
  "fqn": "pulumi_materialize",
  "classes": {
   "materialize:index/view:View": "View"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "materialize",
  "token": "pulumi:providers:materialize",
  "fqn": "pulumi_materialize",
  "class": "Provider"
 }
]
"""
)
