# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetEgressIpsResult',
    'AwaitableGetEgressIpsResult',
    'get_egress_ips',
]

@pulumi.output_type
class GetEgressIpsResult:
    """
    A collection of values returned by GetEgressIps.
    """
    def __init__(__self__, egress_ips=None, id=None, region=None):
        if egress_ips and not isinstance(egress_ips, list):
            raise TypeError("Expected argument 'egress_ips' to be a list")
        pulumi.set(__self__, "egress_ips", egress_ips)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="egressIps")
    def egress_ips(self) -> Sequence[str]:
        """
        The egress IPs in the account
        """
        return pulumi.get(self, "egress_ips")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")


class AwaitableGetEgressIpsResult(GetEgressIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEgressIpsResult(
            egress_ips=self.egress_ips,
            id=self.id,
            region=self.region)


def get_egress_ips(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEgressIpsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_egress_ips()
    pulumi.export("ips", all.egress_ips)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getEgressIps:GetEgressIps', __args__, opts=opts, typ=GetEgressIpsResult).value

    return AwaitableGetEgressIpsResult(
        egress_ips=pulumi.get(__ret__, 'egress_ips'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'))
